record.MarcRecord

|  | ## Cheshire3 Object Model: Class MarcRecord

Module record :: Class MarcRecord

## Class MarcRecord
source code

Object Tree:

    baseObjects.Record --+
                         |
                        MarcRecord

Instance Methods

__repr__(self)
__init__(self, doc, docid=0, store="")
process_xpath(self, xpTuple, maps={}) Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings.
get_dom(self) Return the DOM document node for the record.
get_sax(self) Return the list of SAX events for the record, serialised according to the internal C3 format.
get_xml(self) Return the XML for the record as a serialised string.

Class Variables

Inherited from `baseObjects.Record`: `baseUri`, `dom`, `elementHash`, `history`, `parent`, `processHistory`, `recordStore`, `resultSetItem`, `rights`, `sax`, `schema`, `schemaType`, `status`, `xml`

Method Details

### __repr__(self) (Representation operator) | source code

### __init__(self, doc, docid=0, store="") (Constructor) | source code
Overrides: baseObjects.Record.__init__

### process_xpath(self, xpTuple, maps={}) | source code
Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings. Overrides: baseObjects.Record.process_xpath (inherited documentation)

### get_dom(self) | source code
Return the DOM document node for the record. Overrides: baseObjects.Record.get_dom (inherited documentation)

### get_sax(self) | source code
Return the list of SAX events for the record, serialised according to the internal C3 format. Overrides: baseObjects.Record.get_sax (inherited documentation)

### get_xml(self) | source code
Return the XML for the record as a serialised string. Overrides: baseObjects.Record.get_xml (inherited documentation)